@@ -9,17 +9,17 @@ class VolumesModel : public JSONModel
 public:
     explicit VolumesModel(QObject *parent = nullptr);
     virtual ~VolumesModel();
-    //receive a valid json with a list of volumes
+    // receive a valid json with a list of volumes
     void load(const QString &json) override;
 
-    //QAbstractItemModel methods
+    // QAbstractItemModel methods
     QModelIndex parent(const QModelIndex &index) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
     QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
 
     QString getVolumeId(const QModelIndex &index) const;
