@@ -1,7 +1,11 @@
 #ifndef SELECT_VOLUME_H
 #define SELECT_VOLUME_H
 
-#include "scraper_selector.h"
+#include <QtWidgets>
+
+#include "scraper_results_paginator.h"
+#include "selected_volume_info.h"
+#include "volume_search_query.h"
 
 class QLabel;
 class VolumesModel;
@@ -13,12 +17,12 @@ class ScraperScrollLabel;
 class ScraperTableView;
 class ScraperLineEdit;
 
-class SelectVolume : public ScraperSelector
+class SelectVolume : public QWidget
 {
     Q_OBJECT
 public:
     SelectVolume(QWidget *parent = nullptr);
-    void load(const QString &json, const QString &searchString) override;
+    void load(const QString &json, const VolumeSearchQuery &searchQuery);
     void clearFilter();
     virtual ~SelectVolume();
 
@@ -26,9 +30,14 @@ public slots:
     void loadVolumeInfo(const QModelIndex &mi);
     void setCover(const QByteArray &);
     void setDescription(const QString &jsonDetail);
-    QString getSelectedVolumeId();
-    int getSelectedVolumeNumIssues();
-    QString getSelectedVolumePublisher();
+    SelectedVolumeInfo getSelectedVolumeInfo();
+
+signals:
+    void loadPage(VolumeSearchQuery);
+
+private slots:
+    void loadNextPage();
+    void loadPreviousPage();
 
 private:
     QLabel *cover;
@@ -37,6 +46,9 @@ private:
     VolumesModel *model;
     QSortFilterProxyModel *proxyModel;
     ScraperLineEdit *filterEdit;
+    QString selectedVolumeDescription;
+    VolumeSearchQuery currentSearchQuery;
+    ScraperResultsPaginator *paginator;
 };
 
 #endif // SELECT_VOLUME_H
