@@ -7,17 +7,16 @@ class QRadioButton;
 
 class SeriesQuestion : public QWidget
 {
-	Q_OBJECT
+    Q_OBJECT
 
 public:
-	SeriesQuestion(QWidget * parent = 0);
-	bool getYes();
-	void setYes(bool yes = true);
+    SeriesQuestion(QWidget *parent = nullptr);
+    bool getYes();
+    void setYes(bool yes = true);
 
 private:
-	QRadioButton * yes;
-	QRadioButton * no;
+    QRadioButton *yes;
+    QRadioButton *no;
 };
 
-
 #endif // SERIES_QUESTION_H
