@@ -5,7 +5,7 @@
 #include "httpresponse.h"
 #include "httprequesthandler.h"
 
-class FolderContentControllerV2 : public HttpRequestHandler
+class FolderContentControllerV2 : public stefanfrings::HttpRequestHandler
 {
     Q_OBJECT
     Q_DISABLE_COPY(FolderContentControllerV2)
@@ -14,10 +14,10 @@ public:
     FolderContentControllerV2();
 
     /** Generates the response */
-    void service(HttpRequest &request, HttpResponse &response) override;
+    void service(stefanfrings::HttpRequest &request, stefanfrings::HttpResponse &response) override;
 
 private:
-    void serviceContent(const int &library, const qulonglong &folderId, HttpResponse &response);
+    void serviceContent(const int &library, const qulonglong &folderId, stefanfrings::HttpResponse &response);
 };
 
 #endif // FOLDERCONTENTCONTROLLER_H
