@@ -14,16 +14,18 @@ void LibrariesUpdater::updateIfNeeded()
     libraries.load();
 
     foreach (QString name, libraries.getNames()) {
-        QString path = libraries.getPath(name) + "/.yacreaderlibrary";
+        QString libraryPath = libraries.getPath(name);
+        QString libraryDataPath = YACReader::LibraryPaths::libraryDataPath(libraryPath);
+        QString databasePath = YACReader::LibraryPaths::libraryDatabasePath(libraryPath);
 
         QDir d;
 
         QString dbVersion;
-        if (d.exists(path) && d.exists(path + "/library.ydb") && (dbVersion = DataBaseManagement::checkValidDB(path + "/library.ydb")) != "") {
+        if (d.exists(libraryDataPath) && d.exists(databasePath) && (dbVersion = DataBaseManagement::checkValidDB(databasePath)) != "") {
             int comparation = DataBaseManagement::compareVersions(dbVersion, DB_VERSION);
 
             if (comparation < 0) {
-                bool updated = DataBaseManagement::updateToCurrentVersion(path);
+                bool updated = DataBaseManagement::updateToCurrentVersion(libraryPath);
                 if (!updated) {
                     // TODO log error
                 }
