@@ -39,9 +39,9 @@ public:
     int bookmark1;
     int bookmark2;
     int bookmark3;
-    int brightness;
-    int contrast;
-    int gamma;
+    [[deprecated("Use imageFiltersJson")]] int brightness;
+    [[deprecated("Use imageFiltersJson")]] int contrast;
+    [[deprecated("Use imageFiltersJson")]] int gamma;
     //-----------------
 
     QVariant title; // string
@@ -84,8 +84,6 @@ public:
 
     QVariant comicVineID; // string
 
-    QImage cover;
-
     QVariant lastTimeOpened; // integer/date
     QVariant coverSizeRatio; // h/w
     QVariant originalCoverSize; // string "WxH"
@@ -106,6 +104,12 @@ public:
     QVariant review; // string
     QVariant tags; // string/list
 
+    QVariant imageFiltersJson; // string, JSON with image filters
+    QVariant lastTimeImageFiltersSet; // integer/date, last time image filters were set
+    QVariant lastTimeCoverSet; // integer/date, last time cover was set
+    QVariant usesExternalCover; // bool, whether the cover is external or not
+    QVariant lastTimeMetadataSet; // integer/date, last time metadata was set
+
     QPixmap getCover(const QString &basePath);
 
     Q_INVOKABLE QStringList getWriters();
@@ -189,8 +193,6 @@ public:
 
     Q_PROPERTY(QVariant comicVineID MEMBER comicVineID CONSTANT)
 
-    Q_PROPERTY(QImage cover MEMBER cover CONSTANT)
-
     Q_PROPERTY(QVariant lastTimeOpened MEMBER lastTimeOpened CONSTANT)
 
     Q_PROPERTY(QVariant coverSizeRatio MEMBER coverSizeRatio CONSTANT)
@@ -212,6 +214,12 @@ public:
     Q_PROPERTY(QVariant review MEMBER review CONSTANT)
     Q_PROPERTY(QVariant tags MEMBER tags CONSTANT)
 
+    Q_PROPERTY(QVariant imageFiltersJson MEMBER imageFiltersJson CONSTANT)
+    Q_PROPERTY(QVariant lastTimeImageFiltersSet MEMBER lastTimeImageFiltersSet CONSTANT)
+    Q_PROPERTY(QVariant lastTimeCoverSet MEMBER lastTimeCoverSet CONSTANT)
+    Q_PROPERTY(QVariant usesExternalCover MEMBER usesExternalCover CONSTANT)
+    Q_PROPERTY(QVariant lastTimeMetadataSet MEMBER lastTimeMetadataSet CONSTANT)
+
     //-new properties, not loaded from the DB automatically
     bool isFavorite;
     Q_PROPERTY(bool isFavorite MEMBER isFavorite WRITE setFavorite NOTIFY favoriteChanged)
