@@ -12,8 +12,8 @@
 
 #define PREVIOUS_VERSION "6.0.0"
 
-HttpWorker::HttpWorker(const QString &urlString)
-    : QThread(), url(urlString), _error(false), _timeout(false)
+HttpWorker::HttpWorker(const QString &urlString, const QString &userAgent)
+    : QThread(), url(urlString), userAgent(userAgent), _error(false), _timeout(false)
 {
 }
 
@@ -46,7 +46,13 @@ void HttpWorker::run()
     tT.setSingleShot(true);
     connect(&tT, &QTimer::timeout, &q, &QEventLoop::quit);
     connect(&manager, &QNetworkAccessManager::finished, &q, &QEventLoop::quit);
-    QNetworkReply *reply = manager.get(QNetworkRequest(url));
+
+    auto request = QNetworkRequest(url);
+
+    request.setHeader(QNetworkRequest::UserAgentHeader,
+                      userAgent);
+
+    QNetworkReply *reply = manager.get(request);
 
     tT.start(5000); // 5s timeout
     q.exec();
