@@ -12,7 +12,6 @@ class HelpAboutDialog : public QDialog
 public:
     HelpAboutDialog(QWidget *parent = 0);
     HelpAboutDialog(const QString &pathAbout, const QString &pathHelp, QWidget *parent = 0);
-    ~HelpAboutDialog();
 public slots:
     void loadAboutInformation(const QString &path);
     void loadHelp(const QString &path);
@@ -21,7 +20,9 @@ private:
     QTabWidget *tabWidget;
     QTextBrowser *aboutText;
     QTextBrowser *helpText;
+    QTextBrowser *systemInfoText;
     QString fileToString(const QString &path);
+    void loadSystemInfo();
 };
 
-#endif // HELP_ABOUT_DIALOG_H
\ No newline at end of file
+#endif // HELP_ABOUT_DIALOG_H
